# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.1.0

import winrt.system
from winrt import _winrt_windows_ui_xaml_resources

__all__ = [
    "CustomXamlResourceLoader",
]

CustomXamlResourceLoader = _winrt_windows_ui_xaml_resources.CustomXamlResourceLoader
